pub struct StdioServerTransport { /* private fields */ }Expand description
STDIO transport for MCP servers
This transport communicates with an MCP client via STDIO (standard input/output). It reads requests from stdin and writes responses to stdout.
Implementations
Sourceimpl StdioServerTransport
impl StdioServerTransport
Sourcepub fn with_config(config: TransportConfig) -> Self
pub fn with_config(config: TransportConfig) -> Self
Sourceimpl StdioServerTransport
impl StdioServerTransport
Sourcepub async fn handle_request(
&mut self,
request: JsonRpcRequest,
) -> McpResult<JsonRpcResponse>
pub async fn handle_request( &mut self, request: JsonRpcRequest, ) -> McpResult<JsonRpcResponse>
Backward compatibility method for tests a default response for testing purposes